instrumenttools.Contrabass
==========================

.. abjad-lineage:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass

.. autoclass:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabass.Contrabass.Contrabass.__repr__
   :noindex:
